# haplo

```{image} haplo_logo.png
:width: 400px
```

## Installation

To install `haplo`, use

```shell
pip install haplo
```

Although not required, as is generally good practice for any development project, we highly recommend creating a separate virtual environment for each distinct project. For example, via Conda, creating a virtual environment for a project using `haplo` might look like (be sure to choose a better name)

```
conda create -n project_using_haplo_env python=3.11
```

Then before working, be sure to activate your environment with

```shell
conda activate project_using_haplo_env
```

Then install `haplo` within this environment.

## Getting started

A basic example project can be downloaded [here](https://download-directory.github.io/?url=https%3A%2F%2Fgithub.com%2Fgolmschenk%2Fhaplo_example_application). Be sure to rename the directory to a name that describes your project before getting started.

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

analysis_tools/index
reference_index
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
